@@ -1,12 +1,9 @@
 import argparse
-import configparser
 import pathlib
 import sys
 import locale
 import io
 
-from pytodotxt import TodoTxt
-
 try:
     from pter.curses import run_cursesui
 except ImportError:
@@ -81,6 +78,11 @@ def run():
             print(tr("{programname} is up to date.").format(programname=common.PROGRAMNAME))
         return 0
 
+    # ensure logfile directory
+    if args.log_file is not None:
+        log_path = pathlib.Path(args.log_file).resolve().expanduser().parent
+        log_path.mkdir(parents=True, exist_ok=True)
+
     if args.new_task is not None:
         if len(args.filename) != 1:
             print(tr("You have to provide exactly one todo.txt file."), file=sys.stderr)
